@@ -113,6 +113,7 @@ class GSPeerConnectionBroadcasterPi:
                 self.peerConnections[id] = pc
 
                 video = self.getPiH264Relay()
+                audio = None
 
                 @pc.on("connectionstatechange")
                 async def on_connectionstatechange():
@@ -130,13 +131,12 @@ class GSPeerConnectionBroadcasterPi:
 
                 if self.gsdbs.credentials["audio"]:
                     audio = self.getMicrofonRelay()
-                    transceiver1 = pc.addTransceiver("audio", direction="sendonly")
+                    pc.addTrack(audio)
+                    # transceiver1 = pc.addTransceiver("audio", direction="sendonly")
 
                 for t in pc.getTransceivers():
                     if t.kind == "video":
                         pc.addTrack(video)
-                    if audio is not None and t.kind == "audio":
-                        pc.addTrack(audio)
 
                 await pc.setRemoteDescription(offer)
 
